@@ -1,5 +1,7 @@
 import click
 
+DEBUG = False
+
 
 def error(message):
     __log("ERROR", "red", message)
@@ -13,6 +15,11 @@ def info(message):
     __log("INFO", None, message)
 
 
+def dbg(message):
+    if DEBUG:
+        __log("DEBUG", "cyan", message)
+
+
 def __log(level, color, message):
     click.secho(f"[{level}] ", nl=False, err=True, fg=color, bold=True)
     click.secho(message, err=True, fg=color)
